@@ -3,7 +3,7 @@
 Open Asset Import Library (assimp)
 ---------------------------------------------------------------------------
 
-Copyright (c) 2006-2015, assimp team
+Copyright (c) 2006-2024, assimp team
 
 All rights reserved.
 
@@ -48,17 +48,13 @@ namespace AssimpView {
 //-------------------------------------------------------------------------------
 // Message procedure for the help dialog
 //-------------------------------------------------------------------------------
-INT_PTR CALLBACK HelpDialogProc(HWND hwndDlg,UINT uMsg,
-    WPARAM wParam,LPARAM lParam)
-    {
-    (void)lParam;
-    switch (uMsg)
-        {
+INT_PTR CALLBACK HelpDialogProc(HWND hwndDlg,UINT uMsg, WPARAM wParam,LPARAM ) {
+    switch (uMsg) {
         case WM_INITDIALOG:
-            {
+        {
             // load the help file ...
-            HRSRC res = FindResource(NULL,MAKEINTRESOURCE(IDR_TEXT1),"TEXT");
-            HGLOBAL hg = LoadResource(NULL,res);
+            HRSRC res = FindResource(nullptr,MAKEINTRESOURCE(IDR_TEXT1),"TEXT");
+            HGLOBAL hg = LoadResource(nullptr,res);
             void* pData = LockResource(hg);
 
             SETTEXTEX sInfo;
@@ -70,39 +66,38 @@ INT_PTR CALLBACK HelpDialogProc(HWND hwndDlg,UINT uMsg,
 
             FreeResource(hg);
             return TRUE;
-            }
+        }
 
         case WM_CLOSE:
             EndDialog(hwndDlg,0);
             return TRUE;
 
         case WM_COMMAND:
-
-            if (IDOK == LOWORD(wParam))
-                {
+            if (IDOK == LOWORD(wParam)) {
                 EndDialog(hwndDlg,0);
                 return TRUE;
-                }
+            }
 
         case WM_PAINT:
             {
-            PAINTSTRUCT sPaint;
-            HDC hdc = BeginPaint(hwndDlg,&sPaint);
+                PAINTSTRUCT sPaint;
+                HDC hdc = BeginPaint(hwndDlg,&sPaint);
 
-            HBRUSH hBrush = CreateSolidBrush(RGB(0xFF,0xFF,0xFF));
+                HBRUSH hBrush = CreateSolidBrush(RGB(0xFF,0xFF,0xFF));
 
-            RECT sRect;
-            sRect.left = 0;
-            sRect.top = 26;
-            sRect.right = 1000;
-            sRect.bottom = 507;
-            FillRect(hdc, &sRect, hBrush);
+                RECT sRect;
+                sRect.left = 0;
+                sRect.top = 26;
+                sRect.right = 1000;
+                sRect.bottom = 507;
+                FillRect(hdc, &sRect, hBrush);
 
-            EndPaint(hwndDlg,&sPaint);
-            return TRUE;
+                EndPaint(hwndDlg,&sPaint);
+                return TRUE;
             }
-        };
-    return FALSE;
     }
 
-};
\ No newline at end of file
+    return FALSE;
+}
+
+}
